@@ -70,12 +70,16 @@ module Gem2Deb
     end
 
     EXTENSION_BUILDER = File.expand_path(File.join(File.dirname(__FILE__),'extension_builder.rb'))
-    TEST_RUNNER = File.expand_path(File.join(File.dirname(__FILE__),'testrunner.rb'))
+    TEST_RUNNER = File.expand_path(File.join(File.dirname(__FILE__),'test_runner.rb'))
     LIBDIR = File.expand_path(File.join(File.dirname(__FILE__), '..'))
 
+    attr_accessor :dh_auto_install_destdir
+
     def install(argv)
       puts "  Entering dh_ruby --install" if @verbose
 
+      self.dh_auto_install_destdir = argv.first
+
       supported_versions =
         if all_ruby_versions_supported?
           SUPPORTED_RUBY_VERSIONS.keys.clone
@@ -141,6 +145,24 @@ module Gem2Deb
           end
         end
       end
+
+      install_symlinks(package, supported_versions)
+    end
+
+    def install_symlinks(package, supported_versions)
+      supported_versions.select { |v| v == 'ruby1.8' }.each do |rubyver|
+        archdir = destdir(package, :archdir, rubyver)
+        vendordir = destdir(packages, :libdir, rubyver)
+        vendorlibdir = File.dirname(archdir)
+        Dir.glob(File.join(archdir, '*.so')).each do |so|
+          rb = File.basename(so).gsub(/\.so$/, '.rb')
+          if File.exists?(File.join(vendordir, rb))
+            Dir.chdir(vendorlibdir) do
+              FileUtils.ln_s "../#{rb}", rb
+            end
+          end
+        end
+      end
     end
 
     def remove_duplicate_files(src, dst)
@@ -240,31 +262,11 @@ module Gem2Deb
       if skip_checks?
         return
       end
-      if File::exists?('debian/ruby-test-files.yaml')
-        puts "Running tests for #{rubyver} using gem2deb test runner and debian/ruby-test-files.yaml..."
-        cmd = "#{SUPPORTED_RUBY_VERSIONS[rubyver]} -I#{LIBDIR} #{TEST_RUNNER}"
-        puts(cmd) if $VERBOSE
-        system(cmd)
-      elsif File::exists?('debian/ruby-tests.rb')
-        puts "Running tests for #{rubyver} using debian/ruby-tests.rb..."
-        ENV['RUBY_TEST_VERSION'] = rubyver
-        ENV['RUBY_TEST_BIN'] = SUPPORTED_RUBY_VERSIONS[rubyver]
-        cmd = "#{SUPPORTED_RUBY_VERSIONS[rubyver]} -Ilib debian/ruby-tests.rb"
-        puts(cmd) if $VERBOSE
-        system(cmd)
-      elsif File::exists?('debian/ruby-tests.rake')
-        puts "Running tests for #{rubyver} using debian/ruby-tests.rake..."
-        cmd = [
-          SUPPORTED_RUBY_VERSIONS[rubyver],
-          '-rrake',
-          '-e',
-          'ARGV.unshift("-f", "debian/ruby-tests.rake"); Rake.application.run'
-        ]
-        puts(cmd.join(' ')) if $VERBOSE
-        system(*cmd)
-      else
-        puts "Running tests for #{rubyver}: found no way to run a test suite!"
-      end
+
+      cmd = "#{SUPPORTED_RUBY_VERSIONS[rubyver]} -I#{LIBDIR} #{TEST_RUNNER}"
+      puts(cmd) if $VERBOSE
+      system(cmd)
+
       if $?.exitstatus != 0
         handle_test_failure(rubyver)
         return false
@@ -316,7 +318,13 @@ module Gem2Deb
     end
 
     def destdir_for(package)
-      File.expand_path(File.join('debian', package))
+      destdir =
+        if ENV['DH_RUBY_USE_DH_AUTO_INSTALL_DESTDIR']
+          self.dh_auto_install_destdir
+        else
+          File.join('debian', package)
+        end
+      File.expand_path(destdir)
     end
 
     def update_shebangs(package)
